import { c, cTB, cB, cE, cM, cNotM } from '../../../_utils/cssr'
import fadeInHeightExpandTransition from '../../../_styles/transitions/fade-in-height-expand'

export default c([
  cTB('menu-popover', {
    minWidth: '180px'
  }),
  ({ props }) => {
    const {
      $local: {
        itemTextColor,
        itemTextColorHover,
        itemTextColorChildSelected,
        groupTextColor,
        borderColorHorizontal,
        itemIconColor,
        itemIconColorHover,
        itemIconColorCollapsed,
        itemIconColorSelected,
        itemIconColorChildSelected,
        itemColorMatch,
        itemTextColorSelected,
        itemExtraTextColor,
        itemExtraTextColorHover,
        itemExtraTextColorSelected,
        itemExtraTextColorChildSelected,
        submenuArrowColor,
        borderRadius,
        fontSize
      },
      $global: {
        cubicBezierEaseInOut
      }
    } = props
    return cTB('menu', {
      color: itemTextColor,
      overflow: 'hidden',
      transition: `background-color .3s ${cubicBezierEaseInOut}`,
      width: '100%',
      boxSizing: 'border-box',
      fontSize,
      paddingBottom: '6px'
    }, [
      cM('transition-disabled', [
        cB('menu-item-content', [
          cE('icon', {
            transition: 'none !important'
          })
        ]),
        cB('menu-item-content-header', {
          transition: 'none !important'
        }, [
          cE('extra', {
            transition: 'none !important'
          })
        ])
      ]),
      cM('horizontal', {
        display: 'flex',
        paddingBottom: 0
      }, [
        cB('submenu', {
          margin: 0
        }),
        cB('menu-item', {
          margin: 0
        }, [
          c('&::after', {
            backgroundColor: 'transparent !important'
          }),
          cM('selected', [
            cB('menu-item-content', {
              borderBottom: `2px solid ${borderColorHorizontal}`
            })
          ])
        ]),
        cB('menu-item-content', {
          padding: '0 20px',
          borderBottom: '2px solid transparent'
        }, [
          cM('child-selected', {
            borderBottom: `2px solid ${borderColorHorizontal}`
          }),
          cNotM('disabled', [
            hoverStyle({
              borderBottom: `2px solid ${borderColorHorizontal}`
            })
          ])
        ])
      ]),
      cM('collapsed', [
        cB('menu-item', [
          c('&::after', {
            backgroundColor: 'transparent !important'
          })
        ]),
        cB('menu-item-content', [
          cB('menu-item-content-header', {
            opacity: 0
          }),
          cE('arrow', {
            opacity: 0
          }),
          cE('icon', {
            color: itemIconColorCollapsed
          })
        ])
      ]),
      cB('menu-item', {
        transition: `background-color .3s ${cubicBezierEaseInOut}`,
        height: '42px',
        marginTop: '6px',
        position: 'relative'
      }, [
        c('&::after', {
          raw: `
            content: "";
            background-color: transparent;
            position: absolute;
            left: 8px;
            right: 8px;
            top: 0;
            bottom: 0;
            pointer-events: none;
          `,
          borderRadius,
          transition: `background-color .3s ${cubicBezierEaseInOut}`
        }),
        cNotM('disabled', [
          c('&:active::after', {
            backgroundColor: itemColorMatch
          })
        ]),
        cM('selected', [
          c('&::after', {
            backgroundColor: itemColorMatch
          }),
          cB('menu-item-content', [
            cE('icon', {
              color: itemIconColorSelected
            }),
            cB('menu-item-content-header', {
              color: itemTextColorSelected
            }, [
              cE('extra', {
                color: itemExtraTextColorSelected
              })
            ])
          ])
        ])
      ]),
      cB('menu-item-content', {
        raw: `
          box-sizing: border-box;
          line-height: 1.75;
          height: 100%;
          display: flex;
          align-items: center;
          cursor: pointer;
          position: relative;
          z-index: auto;
          padding-right: 12px;
          transition:
            background-color .3s ${cubicBezierEaseInOut},
            padding-left .3s ${cubicBezierEaseInOut},
            border-color .3s ${cubicBezierEaseInOut};
        `
      }, [
        cM('disabled', {
          opacity: '.45',
          cursor: 'not-allowed'
        }),
        cM('collapsed', [
          cE('arrow', {
            transition: `
              transform 0.2s ${cubicBezierEaseInOut},
              opacity 0.2s ${cubicBezierEaseInOut},
              border-color 0.3s ${cubicBezierEaseInOut}
            `,
            transform: 'rotate(225deg)'
          })
        ]),
        cM('uncollapsable', {
          cursor: 'default'
        }),
        cM('child-selected', [
          cB('menu-item-content-header', {
            color: itemTextColorChildSelected
          }, [
            cE('extra', {
              color: itemExtraTextColorChildSelected
            })
          ]),
          cE('icon', {
            color: itemIconColorChildSelected
          })
        ]),
        cNotM('disabled', [
          cNotM('uncollapsable', [
            hoverStyle(null, [
              cE('icon', {
                color: itemIconColorHover
              }),
              cB('menu-item-content-header', {
                color: itemTextColorHover
              }, [
                cE('extra', {
                  color: itemExtraTextColorHover
                })
              ])
            ])
          ])
        ]),
        cE('icon', {
          raw: `
            color: ${itemIconColor};
            transition:
              color .3s ${cubicBezierEaseInOut},
              font-size .3s ${cubicBezierEaseInOut},
              padding-right .3s ${cubicBezierEaseInOut};
            box-sizing: content-box;
            flex-shrink: 0;
            padding-right: 8px;
            display: inline-flex;
            align-items: center;
            justify-content: center;
          `
        }),
        cE('arrow', {
          raw: `
            content: '';
            height: 6px;
            width: 6px;
            position: absolute;
            right: 24px;
            top: calc(50% - 2px);
            transform: rotate(45deg);
            transform-origin: 25% 25%;
            opacity: 1;
          `,
          borderLeft: `2px solid ${submenuArrowColor}`,
          borderTop: `2px solid ${submenuArrowColor}`,
          transition: `
            transform 0.2s ${cubicBezierEaseInOut},
            opacity 0.2s ${cubicBezierEaseInOut} .1s,
            border-color 0.3s ${cubicBezierEaseInOut}
          `
        }),
        cB('menu-item-content-header', {
          raw: `
            transition:
              color .3s ${cubicBezierEaseInOut},
              opacity .3s ${cubicBezierEaseInOut};
            opacity: 1;
            flex-grow: 1;
            flex-shrink: 1;
            white-space: nowrap;
            overflow: hidden;
            text-overflow: ellipsis;
          `,
          color: itemTextColor
        }, [
          cE('extra', {
            raw: `
              white-space: nowrap;
              margin-left: 6px;
              display: inline-block;
              transition: color 0.3s ${cubicBezierEaseInOut};
              font-size: 13px;
            `,
            color: itemExtraTextColor
          })
        ])
      ]),
      cB('submenu', {
        cursor: 'pointer',
        position: 'relative',
        marginTop: '6px'
      }, [
        cB('menu-item-content', {
          height: '42px'
        }),
        cB('submenu-children', {
          overflow: 'hidden',
          padding: 0
        }, [
          fadeInHeightExpandTransition({
            duration: '.2s'
          })
        ])
      ]),
      cB('menu-item-group', [
        cB('menu-item-group-title', {
          raw: `
            margin-top: 6px;
            color: ${groupTextColor};
            cursor: default;
            font-size: 13px;
            height: 36px;
            display: flex;
            align-items: center;
            transition:
              padding-left .3s ${cubicBezierEaseInOut},
              color .3s ${cubicBezierEaseInOut};
          `
        })
      ])
    ])
  }
])

function hoverStyle (props, children) {
  return [
    cM('hover', props, children),
    c('&:hover', props, children)
  ]
}
